<?php
App::uses('EvShippingAppModel', 'EvShipping.Model');
/**
 * Zone Model
 *
 * @property Country $Country
 * @property ZoneExtra $ZoneExtra
 * @property ShippingRule $ShippingRule
 */
class Zone extends EvShippingAppModel {

	/**
	 * Display field
	 *
	 * @var string
	 */
	public $displayField = 'name';

	/**
	 * Validation rules
	 *
	 * @var array
	 */
	public $validate = array(
		'country_id' => array(
			'numeric' => array(
				'rule' => array('numeric'),
				'message' => 'Please select a country to link this Zone to'
			),
		),
		'name' => array(
			'notBlank' => array(
				'rule' => array('notBlank'),
				'message' => 'Please enter a name for this Zone'
			),
		),
	);

	//The Associations below have been created with all possible keys, those that are not needed can be removed

	/**
	 * belongsTo associations
	 *
	 * @var array
	 */
	public $belongsTo = array(
		'Country' => array(
			'className' => 'EvCountry.Country'
		)
	);

	/**
	 * hasMany associations
	 *
	 * @var array
	 */
	public $hasMany = array(
		'ZoneExtra' => array(
			'className' => 'EvShipping.ZoneExtra'
		)
	);

	/**
	 * hasAndBelongsToMany associations
	 *
	 * @var array
	 */
	public $hasAndBelongsToMany = array(
		'ShippingRule' => array(
			'className' => 'EvShipping.ShippingRule',
			'joinTable' => 'ev_shipping_shipping_rules_zones'
		)
	);

	/**
	 * readForEdit - retrieve the zone extra data
	 *
	 * @param integer $id ID of row to edit
	 * @param array $query The db query array - can be used to pass in additional parameters such as contain
	 * @return array
	 */
	public function readForEdit($id, $query = array()) {
		$query['contain'][] = 'ZoneExtra';

		return parent::readForEdit($id, $query);
	}

	/**
	 * Called after each successful save operation.
	 *
	 * @param bool $created True if this save created a new record
	 * @param array $options Options passed from Model::save().
	 * @return void
	 * @link http://book.cakephp.org/2.0/en/models/callback-methods.html#aftersave
	 * @see Model::save()
	 */
	public function afterSave($created, $options = array()) {
		parent::afterSave($created, $options);

		// process any custom field deletions
		if (! empty($this->data[$this->alias]['ZoneExtraDeletes']['toDelete'])) {

			$ids = explode(',', $this->data[$this->alias]['ZoneExtraDeletes']['toDelete']);
			$ids = ArrayUtil::clearArray($ids);

			$this->ZoneExtra->deleteAll(
				array(
					'ZoneExtra.id' => $ids
				),
				true,
				true
			);
		}
	}
}
